/*
Copyright (c) 2011 Nils Fett

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), 
to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, 
and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, 
INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/


function IsNumeric(val) {
    return Number(parseFloat(val))==val;
}


function getPosition(el) {
  var xPos = 0;
  var yPos = 0;
 
  while (el) {
    if (el.tagName == "BODY") {
      // deal with browser quirks with body/window/document and page scroll
      var xScroll = el.scrollLeft || document.documentElement.scrollLeft;
      var yScroll = el.scrollTop || document.documentElement.scrollTop;
 
      xPos += (el.offsetLeft - xScroll + el.clientLeft);
      yPos += (el.offsetTop - yScroll + el.clientTop);
    } else {
      // for all other non-BODY elements
      xPos += (el.offsetLeft - el.scrollLeft + el.clientLeft);
      yPos += (el.offsetTop - el.scrollTop + el.clientTop);
    }
 
    el = el.offsetParent;
  }
  return {
    x: xPos,
    y: yPos
  };
}

var oChart = {
	canvas:null,
	currentSpan:2,
	currentVoltType:1,
	spans:[3600000,21600000,86400000,172800000,604800000],
	startChart:0,
	endChart:0,
	min:[5.95,12,24],
	max:[6.3,12.55,25.05],
	spanPixels:40,
	offsetTop:50,
	offsetBottom:80,
	chartHeight:140,
	canvasLeft:0,
	init:function(){
		if(ui.activeDevice == 0){
			return;
		}
		this.data = app.devices[ui.activeDevice].scans;
		this.currentVoltType = app.devices[ui.activeDevice].voltType
		if(this.currentVoltType == '?' || this.data.length == 0){
			this.data = [];
			this.startChart = Date.now();
			this.endChart = Date.now();
		}
		else{
			this.startChart = this.data[0][0] - ( this.data[0][0] / this.spans[this.currentSpan] );
			this.endChart = this.data[(this.data.length-1)][0] - ( this.data[0][0] / this.spans[this.currentSpan] ) + this.spans[this.currentSpan];
		}
		
		for(var i = 0; i < this.data.length; i++){
			this.data[i][2] = ( ( this.data[i][0] - this.startChart ) / this.spans[this.currentSpan] * this.spanPixels );
			var volt = this.data[i][1];
			if( volt < this.min[this.currentVoltType]) volt = this.min[this.currentVoltType];
			if( volt > this.max[this.currentVoltType]) volt = this.max[this.currentVoltType];
			this.data[i][3] = this.chartHeight - (this.chartHeight / (  ( ( this.max[this.currentVoltType] - this.min[this.currentVoltType] ) / ( (volt-this.min[this.currentVoltType]) ) ) ) ) + this.offsetTop;
		}
		this.canvas = document.getElementById("cv");
		this.ctx = this.canvas.getContext("2d");
		this.draw();
		this.canvasLeft = ($('#cv').width()-$('#frame').width()) * -1;
		$('#canvas-margin').css({left:this.canvasLeft});
		$( ".dot" ).off('click');
		$( ".dot" ).on('click', function() {
			$( ".dot" ).show();
			$(this).hide();
			$( ".dotInfo" ).hide();
			$(this).next().show()
		});	
	},
	draw:function(){
		this.canvas.height = $('#frame').height();
		var neededWidth = ( ( ( this.endChart - this.startChart) / this.spans[this.currentSpan] ) + 2 ) * this.spanPixels;
		if( neededWidth > $('#frame').width()){
			$('#canvas-margin').width(neededWidth);
			this.canvas.width = neededWidth;
		}
		else{			
			$('#canvas-margin').width($('#frame').width());
			this.canvas.width = $('#frame').width();
		}
		this.ctx.clearRect(0, 0, this.canvas.width, this.canvas.height);
		this.ctx.font = "10px Arial";
		this.ctx.fillStyle = "rgba(255,255,255,1)";
			
		var step = 	this.startChart;

		if( ! IsNumeric (step) ){
			step = Date.now();
		}
		var stepPixels = 0;
		
		while(stepPixels <= this.canvas.width){
			this.ctx.lineWidth = "1";
			this.ctx.strokeStyle = "rgba(255,255,255,1)";
			
			this.ctx.beginPath();
			this.ctx.moveTo(stepPixels, 0);			
			this.ctx.lineTo(stepPixels, this.chartHeight + this.offsetTop);
			this.ctx.stroke();

			var currentTime = new Date(step);
			var Year = currentTime.getFullYear();
			var Month = currentTime.getMonth();
			var Day = currentTime.getDate();
			var Hour = currentTime.getHours();
			var Minutes = currentTime.getMinutes();
			
			this.ctx.textAlign = "center";
			this.ctx.fillText(Year, ( stepPixels + ( this.spanPixels / 2 ) ) , 15);
			this.ctx.fillText(Day+'.'+(Month+1), ( stepPixels + ( this.spanPixels / 2 ) ) , 30);
			//this.ctx.fillText(Hour+':00', ( stepPixels + ( this.spanPixels / 2 ) ) , 45);
			
			step += this.spans[this.currentSpan];
			stepPixels += this.spanPixels;
		}
		
		$('.dot, .dotInfo').remove();
		if(this.data.length){
			var dotInfo = $('<div class="dotInfo" style="display:none;margin:'+(this.data[0][3]-25)+'px 0 0 '+( ( this.data[0][2] + ( this.spanPixels / 2 ) )-25 )+'px;">'+this.data[0][1]+' V</div>');			
			$('#canvas-margin').prepend(dotInfo);
			var dot = $('<div class="dot" style="margin:'+(this.data[0][3]-5)+'px 0 0 '+( ( this.data[0][2] + ( this.spanPixels / 2 ) )-5 )+'px;"></div>');			
			$('#canvas-margin').prepend(dot);
			for(var j = 1; j < this.data.length; j++){
				this.ctx.lineWidth = "4";
				this.ctx.strokeStyle = "rgba(255,255,255,0.3)";
				this.ctx.beginPath();
				this.ctx.moveTo(( this.data[j-1][2] + ( this.spanPixels / 2 ) ), this.data[j-1][3]);
				this.ctx.lineTo(( this.data[j][2] + ( this.spanPixels / 2 ) ), this.data[j][3]);
				this.ctx.stroke();

				var dotInfo = $('<div class="dotInfo" style="display:none;margin:'+(this.data[j][3]-25)+'px 0 0 '+( ( this.data[j][2] + ( this.spanPixels / 2 ) )-25 )+'px;">'+this.data[j][1]+' V</div>');			
				$('#canvas-margin').prepend(dotInfo);
				var dot = $('<div class="dot" style="margin:'+(this.data[j][3]-5)+'px 0 0 '+( ( this.data[j][2] + ( this.spanPixels / 2 ) )-5 )+'px;"></div>');			
				$('#canvas-margin').prepend(dot);
			}
		}
	}
};		


$(window).load(function(){
		
});
